︠00609ad7-0f6f-491b-9d0c-a897b964e297s︠
%typeset_mode False
from scipy import special as sp
from scipy import integrate
from sage.symbolic.integration.integral import indefinite_integral
import numpy as np
import math

︡609fcf85-1945-422f-a196-2577db7e9b87︡{"done":true}︡
︠3018e3c9-4796-4f96-9095-8143c385a8b4s︠
var('x, xi')

x_nodes = [-1, 1]
xi_LGL = [-1.0,           \
          -0.87174014851, \
          -0.591700181433,\
          -0.209299217902,\
          0.209299217902, \
          0.591700181433, \
          0.87174014851,  \
          1.0]

lobatto_weights = [0.03571428571429,\
                   0.21070422714351,\
                   0.34112269248350,\
                   0.41245879465870,\
                   0.41245879465870,\
                   0.34112269248350,\
                   0.21070422714351,\
                   0.03571428571429]

︡c4632539-b9a3-47c4-9de9-03601e98b389︡{"stdout":"(x, xi)\n"}︡{"done":true}︡
︠c4ae97f1-e23a-4fc9-96da-4278b439d041s︠
L = [xi, xi, xi, xi, xi, xi, xi, xi]
︡66900d15-d708-4db7-8304-e9e55689273b︡{"done":true}︡
︠744799ea-ac0d-4327-ba68-397d2e1e42e3s︠
#Assigning L_0 and L_1 as the lagrange basis polynomials.
L[0] =    ((xi - (xi_LGL[1])) / (xi_LGL[0] - xi_LGL[1]))\
        * ((xi - (xi_LGL[2])) / (xi_LGL[0] - xi_LGL[2]))\
        * ((xi - (xi_LGL[3])) / (xi_LGL[0] - xi_LGL[3]))\
        * ((xi - (xi_LGL[4])) / (xi_LGL[0] - xi_LGL[4]))\
        * ((xi - (xi_LGL[5])) / (xi_LGL[0] - xi_LGL[5]))\
        * ((xi - (xi_LGL[6])) / (xi_LGL[0] - xi_LGL[6]))\
        * ((xi - (xi_LGL[7])) / (xi_LGL[0] - xi_LGL[7]))

L[1] =    ((xi - (xi_LGL[0])) / (xi_LGL[1] - xi_LGL[0]))\
        * ((xi - (xi_LGL[2])) / (xi_LGL[1] - xi_LGL[2]))\
        * ((xi - (xi_LGL[3])) / (xi_LGL[1] - xi_LGL[3]))\
        * ((xi - (xi_LGL[4])) / (xi_LGL[1] - xi_LGL[4]))\
        * ((xi - (xi_LGL[5])) / (xi_LGL[1] - xi_LGL[5]))\
        * ((xi - (xi_LGL[6])) / (xi_LGL[1] - xi_LGL[6]))\
        * ((xi - (xi_LGL[7])) / (xi_LGL[1] - xi_LGL[7]))

L[2] =    ((xi - (xi_LGL[0])) / (xi_LGL[2] - xi_LGL[0]))\
        * ((xi - (xi_LGL[1])) / (xi_LGL[2] - xi_LGL[1]))\
        * ((xi - (xi_LGL[3])) / (xi_LGL[2] - xi_LGL[3]))\
        * ((xi - (xi_LGL[4])) / (xi_LGL[2] - xi_LGL[4]))\
        * ((xi - (xi_LGL[5])) / (xi_LGL[2] - xi_LGL[5]))\
        * ((xi - (xi_LGL[6])) / (xi_LGL[2] - xi_LGL[6]))\
        * ((xi - (xi_LGL[7])) / (xi_LGL[2] - xi_LGL[7]))

L[3] =    ((xi - (xi_LGL[0])) / (xi_LGL[3] - xi_LGL[0]))\
        * ((xi - (xi_LGL[1])) / (xi_LGL[3] - xi_LGL[1]))\
        * ((xi - (xi_LGL[2])) / (xi_LGL[3] - xi_LGL[2]))\
        * ((xi - (xi_LGL[4])) / (xi_LGL[3] - xi_LGL[4]))\
        * ((xi - (xi_LGL[5])) / (xi_LGL[3] - xi_LGL[5]))\
        * ((xi - (xi_LGL[6])) / (xi_LGL[3] - xi_LGL[6]))\
        * ((xi - (xi_LGL[7])) / (xi_LGL[3] - xi_LGL[7]))

L[4] =    ((xi - (xi_LGL[0])) / (xi_LGL[4] - xi_LGL[0]))\
        * ((xi - (xi_LGL[1])) / (xi_LGL[4] - xi_LGL[1]))\
        * ((xi - (xi_LGL[2])) / (xi_LGL[4] - xi_LGL[2]))\
        * ((xi - (xi_LGL[3])) / (xi_LGL[4] - xi_LGL[3]))\
        * ((xi - (xi_LGL[5])) / (xi_LGL[4] - xi_LGL[5]))\
        * ((xi - (xi_LGL[6])) / (xi_LGL[4] - xi_LGL[6]))\
        * ((xi - (xi_LGL[7])) / (xi_LGL[4] - xi_LGL[7]))

L[5] =    ((xi - (xi_LGL[0])) / (xi_LGL[5] - xi_LGL[0]))\
        * ((xi - (xi_LGL[1])) / (xi_LGL[5] - xi_LGL[1]))\
        * ((xi - (xi_LGL[2])) / (xi_LGL[5] - xi_LGL[2]))\
        * ((xi - (xi_LGL[3])) / (xi_LGL[5] - xi_LGL[3]))\
        * ((xi - (xi_LGL[4])) / (xi_LGL[5] - xi_LGL[4]))\
        * ((xi - (xi_LGL[6])) / (xi_LGL[5] - xi_LGL[6]))\
        * ((xi - (xi_LGL[7])) / (xi_LGL[5] - xi_LGL[7]))

L[6] =    ((xi - (xi_LGL[0])) / (xi_LGL[6] - xi_LGL[0]))\
        * ((xi - (xi_LGL[1])) / (xi_LGL[6] - xi_LGL[1]))\
        * ((xi - (xi_LGL[2])) / (xi_LGL[6] - xi_LGL[2]))\
        * ((xi - (xi_LGL[3])) / (xi_LGL[6] - xi_LGL[3]))\
        * ((xi - (xi_LGL[4])) / (xi_LGL[6] - xi_LGL[4]))\
        * ((xi - (xi_LGL[5])) / (xi_LGL[6] - xi_LGL[5]))\
        * ((xi - (xi_LGL[7])) / (xi_LGL[6] - xi_LGL[7]))

L[7] =    ((xi - (xi_LGL[0])) / (xi_LGL[7] - xi_LGL[0]))\
        * ((xi - (xi_LGL[1])) / (xi_LGL[7] - xi_LGL[1]))\
        * ((xi - (xi_LGL[2])) / (xi_LGL[7] - xi_LGL[2]))\
        * ((xi - (xi_LGL[3])) / (xi_LGL[7] - xi_LGL[3]))\
        * ((xi - (xi_LGL[4])) / (xi_LGL[7] - xi_LGL[4]))\
        * ((xi - (xi_LGL[5])) / (xi_LGL[7] - xi_LGL[5]))\
        * ((xi - (xi_LGL[6])) / (xi_LGL[7] - xi_LGL[6]))

        
︡23001fe0-e481-49f6-985d-168ecf5d5f7d︡{"done":true}︡
︠287034a9-6e50-4156-9fd6-8fdc4cc32814︠
︡4cdfe8c5-eaf2-4347-b50f-f7e440d5a591︡
︠b39dd502-fc20-4cfd-a446-553dedd1653es︠
numerical_integral(L[0] * L[1], -1, 1)[0]
︡612c8651-fba1-4ecb-98cf-f513442333a7︡{"stdout":"0.005783175201965206\n"}︡{"done":true}︡
︠b637b5f8-2d03-434d-a60c-68262b5fbd26s︠

︡78e442c8-8556-4901-8ac0-30e57f749f31︡{"done":true}︡
︠c684df43-5bee-4076-9a5f-4b9d05b2aeecs︠

for i in range (0, 8):
    print(i, '\n')
    for j in range(0, 8):
        numerical_integral(L[i] * L[j], -1, 1)[0]
︡b39a3bb3-7f42-4a9a-aae9-f94f0195e3a5︡{"stdout":"(0, '\\n')\n0.03333333333332194\n0.005783175201965206\n-0.007358427761753982\n0.008091331778355441\n-0.008091331778233877\n0.007358427761705623\n-0.005783175202249493\n0.002380952380963754\n(1, '\\n')\n0.005783175201965206\n0.19665727866729804\n0.017873132323192046\n-0.01965330750343234\n0.019653307503020866\n-0.017873132322725152\n0.014046948476303067\n-0.005783175202249493\n(2, '\\n')\n-0.007358427761753982\n0.017873132323192046\n0.31838117965137114\n0.025006581762566073\n-0.025006581761945083\n0.022741512832051156\n-0.017873132322725152\n0.007358427761705624\n(3, '\\n')\n0.008091331778355441\n-0.01965330750343234\n0.025006581762566073\n0.3849615416814164\n0.027497252976343693\n-0.025006581761945083\n0.019653307503020863\n-0.008091331778233875\n(4, '\\n')\n-0.008091331778233877\n0.019653307503020866\n-0.025006581761945083\n0.027497252976343693\n0.3849615416814164\n0.025006581762566073\n-0.019653307503432346\n0.008091331778355443"}︡{"stdout":"\n(5, '\\n')\n0.007358427761705623\n-0.017873132322725152\n0.022741512832051156\n-0.025006581761945083\n0.025006581762566073\n0.31838117965137114\n0.017873132323192046\n-0.0073584277617539835\n(6, '\\n')\n-0.005783175202249493\n0.014046948476303067\n-0.017873132322725152\n0.019653307503020863\n-0.019653307503432346\n0.017873132323192046\n0.19665727866729804\n0.0057831752019652065\n(7, '\\n')\n0.002380952380963754\n-0.005783175202249493\n0.007358427761705624\n-0.008091331778233875\n0.008091331778355443\n-0.0073584277617539835\n0.0057831752019652065\n0.033333333333321946\n"}︡{"done":true}︡
︠bca7d5b5-eaca-4108-a010-16864e3832dfs︠

︡de813968-947b-4e9d-860c-74dec9292baf︡{"done":true}︡
︠c298c762-bdc6-4686-8ee4-242ea9fd69c3︠
LGL_list = [ \
[-1.0,1.0],                                                               \
[-1.0,0.0,1.0],                                                           \
[-1.0,-0.4472135955,0.4472135955,1.0],                                    \
[-1.0,-0.654653670708,0.0,0.654653670708,1.0],                            \
[-1.0,-0.765055323929,-0.285231516481,0.285231516481,0.765055323929,1.0], \
[-1.0,-0.830223896279,-0.468848793471,0.0,0.468848793471,0.830223896279,  \
1.0],                                                                     \
[-1.0,-0.87174014851,-0.591700181433,-0.209299217902,0.209299217902,      \
0.591700181433,0.87174014851,1.0],                                        \
[-1.0,-0.899757995411,-0.677186279511,-0.363117463826,0.0,0.363117463826, \
0.677186279511,0.899757995411,1.0],                                       \
[-1.0,-0.919533908167,-0.738773865105,-0.47792494981,-0.165278957666,     \
0.165278957666,0.47792494981,0.738773865106,0.919533908166,1.0],          \
[-1.0,-0.934001430408,-0.784483473663,-0.565235326996,-0.295758135587,    \
0.0,0.295758135587,0.565235326996,0.784483473663,0.934001430408,1.0],     \
[-1.0,-0.944899272223,-0.819279321644,-0.632876153032,-0.399530940965,    \
-0.136552932855,0.136552932855,0.399530940965,0.632876153032,             \
0.819279321644,0.944899272223,1.0],                                       \
[-1.0,-0.953309846642,-0.846347564652,-0.686188469082,-0.482909821091,    \
-0.249286930106,0.0,0.249286930106,0.482909821091,0.686188469082,         \
0.846347564652,0.953309846642,1.0],                                       \
[-0.999999999996,-0.959935045274,-0.867801053826,-0.728868599093,         \
-0.550639402928,-0.342724013343,-0.116331868884,0.116331868884,           \
0.342724013343,0.550639402929,0.728868599091,0.86780105383,               \
0.959935045267,1.0],                                                      \
[-0.999999999996,-0.965245926511,-0.885082044219,-0.763519689953,         \
-0.60625320547,-0.420638054714,-0.215353955364,0.0,0.215353955364,        \
0.420638054714,0.60625320547,0.763519689952,0.885082044223,               \
0.965245926503,1.0],                                                      \
[-0.999999999984,-0.9695680463,-0.899200533072,-0.792008291871,           \
-0.65238870288,-0.486059421887,-0.299830468901,-0.101326273522,           \
0.101326273522,0.299830468901,0.486059421887,0.652388702882,              \
0.792008291863,0.899200533092,0.969568046272,0.999999999999]]             \

︡6517bb76-4694-48cc-8d85-d4236fba3d0c︡{"done":true}︡
︠3fa31218-19f9-4b22-82a6-1095261c730fs︠
def L0_L1(xi_LGL):
    xi_LGL = np.array(xi_LGL)
    lagrange_basis_poly = []
    
    for j in np.arange(xi_LGL.shape[0]):
        lagrange_basis_j = np.poly1d([1])
        
        for m in np.arange(xi_LGL.shape[0]):
            if m != j:
                lagrange_basis_j *= np.poly1d([1, -xi_LGL[m]]) \
                                    / (xi_LGL[j] - xi_LGL[m])
        lagrange_basis_poly.append(lagrange_basis_j)
    
    return lagrange_basis_poly[0] * lagrange_basis_poly[1]
︡ca7ee27a-537f-49ec-8820-e3410439b78f︡{"done":true}︡
︠992b903c-915b-4c2d-a30b-498fce942af1s︠
print(L0_L1(LGL_points))
︡46512aae-96d0-4f67-bc8b-38dd5a0b58f6︡{"stderr":"Error in lines 1-1\nTraceback (most recent call last):\n  File \"/cocalc/lib/python2.7/site-packages/smc_sagews/sage_server.py\", line 995, in execute\n    exec compile(block+'\\n', '', 'single') in namespace, locals\n  File \"\", line 1, in <module>\n  File \"\", line 4, in L0_L1\nIndexError: tuple index out of range\n"}︡{"done":true}︡
︠4b7f5139-3dce-4a7c-991f-d4b87c16ec37s︠
numerical_integral(L0_L1(LGL_list[6]), -1, 1)
︡2bc9f854-1e52-4d92-b1b0-7c3fd50041bc︡{"stdout":"(0.005783175201964073, 4.71163122450593e-16)\n"}︡{"done":true}︡
︠460b2049-c04d-418f-be50-48874be45038s︠
for i in range(0,28):
    print(numerical_integral(L0_L1(LGL_list[i]), -1, 1)[0])
︡713e41c9-fdeb-4d76-912f-f3b36351cb5f︡{"stdout":"0.333333333333\n0.133333333333\n0.05323971375\n0.0259259259259\n0.014440434437\n0.00883182542957\n0.00578317520196\n0.00398834520818\n0.00286460651796\n0.00212583206228\n0.00162049687462\n0.00126330203786\n0.00100374856554\n0.000810649719457\n0.000664040592284\n"}︡{"stderr":"Error in lines 1-2\nTraceback (most recent call last):\n  File \"/cocalc/lib/python2.7/site-packages/smc_sagews/sage_server.py\", line 995, in execute\n    exec compile(block+'\\n', '', 'single') in namespace, locals\n  File \"\", line 2, in <module>\nIndexError: list index out of range\n"}︡{"done":true}︡
︠a5fb3e23-37f4-4d9a-af55-d0bdfc560d67s︠
def LGL_points(N):
    xi                 = np.poly1d([1, 0])
    legendre_N_minus_1 = N * (xi * sp.legendre(N - 1) - sp.legendre(N))
    lgl_points         = legendre_N_minus_1.r
    lgl_points.sort()
    lgl_points         = (lgl_points)
    
    return lgl_points
︡cd446d6a-9089-4ab7-a69f-5f4022533fd4︡{"done":true}︡
︠d033b062-6775-41aa-aee4-6a65d22992d0s︠
print(LGL_points(7))
︡ec9ec681-d232-4bb5-9f83-703ddc5d03fe︡{"stdout":"[-1.         -0.8302239  -0.46884879  0.          0.46884879  0.8302239   1.        ]\n"}︡{"done":true}︡
︠a118cbc7-9a28-4a83-a3dc-c3bd6eaf2921s︠
print(numerical_integral(L0_L1(LGL_points(8)), -1, 1))
︡c990d960-64f0-43f9-ac71-68b9ad070f91︡{"stdout":"(0.00578317520220532, 4.711631224498659e-16)\n"}︡{"done":true}︡
︠e97b746e-2f33-43ed-a80b-d07ec66fb8dcs︠
for i in range (3, 30):
    print(numerical_integral(L0_L1(LGL_points(i)), -1, 1))
︡681b9e5e-e6db-4623-8e5f-00442299f84b︡{"stdout":"(0.13333333333333341, 2.7731031508685677e-15)\n(0.05323971374999505, 1.7332838543151235e-15)\n(0.025925925925926265, 1.1568373972098388e-15)\n(0.014440434436697796, 8.180747765513089e-16)\n(0.008831825429837327, 6.058503004859771e-16)\n(0.00578317520220532, 4.711631224498659e-16)\n(0.003988345207907132, 3.7296603402372665e-16)\n(0.0028646065180825096, 3.0374974956255124e-16)\n(0.0021258320621168345, 2.5226541016198267e-16)\n(0.0016204968750730782, 5.567157207471083e-16)\n(0.0012633020355843898, 1.8164735277876645e-16)\n(0.001003748564545736, 2.2338228618937467e-14)\n(0.0008106497277544586, 6.454994913541323e-13)\n(0.0006640406604325044, 1.5566421968657747e-12)\n(0.0005507393097814919, 4.7083985358726706e-11)"}︡{"stdout":"\n(0.0004618008552699972, 2.1039684070047994e-10)\n(0.00039103100441685167, 7.277576934275988e-10)\n(0.00033398425097875384, 4.474912702644648e-09)\n(0.00028756185227232593, 5.894733002978138e-07)\n(0.00024821818705448266, 6.75715008280175e-07)"}︡{"stdout":"\n(0.00021808168014934384, 1.5054891962539568e-06)"}︡{"stdout":"\n(0.00019254567973207468, 3.4873510873850225e-05)"}︡{"stdout":"\n(0.00019143453010449118, 0.00019140574954508706)"}︡{"stdout":"\n(-0.000672459855719221, 0.000349735858050207)"}︡{"stdout":"\n(0.001327500977237568, 0.00195693446895412)"}︡{"stdout":"\n(0.008536201682912633, 0.009403991970390362)"}︡{"stdout":"\n(0.032276067956334815, 0.03684427040090083)"}︡{"stdout":"\n"}︡{"done":true}︡
︠bf48f210-bb65-4cea-80ee-27c42c785e2bs︠
print((L0_L1(LGL_points(30))))
︡7cc52c83-e910-4b96-a258-82a51e44f07d︡{"stdout":"            58             57             56             55\n-9.096e+12 x  + 1.812e+13 x  + 1.118e+14 x  - 2.406e+14 x \n              54            53             52             51\n - 6.386e+14 x  + 1.51e+15 x  + 2.241e+15 x  - 5.962e+15 x \n              50            49             48             47\n - 5.366e+15 x  + 1.66e+16 x  + 9.147e+15 x  - 3.468e+16 x \n              46             45             44             43\n - 1.107e+16 x  + 5.644e+16 x  + 8.721e+15 x  - 7.334e+16 x \n              42             41            40             39\n - 2.335e+15 x  + 7.738e+16 x  - 4.86e+15 x  - 6.706e+16 x \n             38            37             36             35\n + 9.24e+15 x  + 4.81e+16 x  - 9.544e+15 x  - 2.869e+16 x \n              34             33             32             31\n + 7.122e+15 x  + 1.427e+16 x  - 4.133e+15 x  - 5.914e+15 x \n             30             29            28             27\n + 1.92e+15 x  + 2.041e+15 x  - 7.23e+14 x  - 5.843e+14 x \n              26            25             24             23\n + 2.217e+14 x  + 1.38e+14 x  - 5.531e+13 x  - 2.665e+13 x \n              22             21             20             19\n + 1.118e+13 x  + 4.169e+12 x  - 1.814e+12 x  - 5.209e+11 x \n              18             17            16             15\n + 2.337e+11 x  + 5.106e+10 x  - 2.35e+10 x  - 3.837e+09 x \n              14             13             12             11\n + 1.803e+09 x  + 2.143e+08 x  - 1.024e+08 x  - 8.537e+06 x \n              10             9             8        7        6\n + 4.136e+06 x  + 2.285e+05 x - 1.119e+05 x - 3761 x + 1856 x\n          5        4          3           2\n + 32.85 x - 16.3 x - 0.1139 x + 0.05663 x + 0.0001312 x - 6.532e-05\n"}︡{"done":true}︡
︠0f35cf88-7e8b-46e0-910f-88d191ff851as︠
numerical_integral(9.096e12 * x**58, -1, 1)
︡6ba387d5-9dcd-4613-8a43-6556b5cc0b0a︡{"stdout":"(308338983050.84705, 0.0034232503837255627)\n"}︡{"done":true}︡
︠89b444fa-59aa-431e-8cfe-ec5909339ab4s︠
from sage.symbolic.integration.integral import definite_integral
︡6487e572-4a2a-4b9a-abb7-f6ded6683100︡{"done":true}︡
︠0165facd-1a5a-42c6-9b34-1a7d1a6c99abs︠
definite_integral(9.096e12 * x**58,x,-1,1)
︡507c7034-1674-4b49-8a1b-9ce067749872︡{"stdout":"308338983050.8475\n"}︡{"done":true}︡
︠629e3834-8b21-4289-be62-6ae5e33337ffs︠
x = np.poly1d([1, 0])
y = np.poly1d([1, 0])
︡9fe9b73d-ac0b-4764-b279-9f6df9abffd9︡{"done":true}︡
︠636f2912-64f8-429a-9e3b-1d45b0f1ae3fs︠
for i in range(0,57):
    x = x*y
︡b95d18d1-0e95-4e14-a49c-fc00a9bf4e56︡{"done":true}︡
︠f05f9c24-aa29-46e9-8e93-22b442795c6fs︠
print(x)
︡42ee96f1-0b73-45eb-9069-1383b83d8e6c︡{"stdout":"   58\n1 x \n"}︡{"done":true}︡
︠fbf50f2a-c5bb-4a2f-b32f-49c74936c1c1s︠
print(np.poly1d.integ(9.096e12 * x)(1) - np.poly1d.integ(9.096e12 * x)(-1) - 308338983050.)
︡38cb2b5a-89a7-435e-82d6-d368b0cd0e56︡{"stdout":"0.847473144531\n"}︡{"done":true}︡
︠5e20a836-025f-4517-831a-8aef6af79b16s︠
definite_integral(9.096e12 * x**58,x,-1,1) - numerical_integral(9.096e12 * x**58, -1, 1)[0]
︡3fa93365-44be-4998-8eb4-a552fde9f80f︡{"stdout":"0.00042724609375\n"}︡{"done":true}︡︡
︠b9a5fde0-c060-45c9-96e7-5ba4c3048cbbs︠
for i in range (3, 30):
    print(definite_integral(L0_L1(LGL_points(i)), x, -1, 1))
︡1b79ccb8-2ffa-4824-ae50-c02c327ae41b︡{"stderr":"Error in lines 1-2\nTraceback (most recent call last):\n  File \"/cocalc/lib/python2.7/site-packages/smc_sagews/sage_server.py\", line 995, in execute\n    exec compile(block+'\\n', '', 'single') in namespace, locals\n  File \"\", line 2, in <module>\n  File \"sage/symbolic/function.pyx\", line 996, in sage.symbolic.function.BuiltinFunction.__call__ (/ext/sage/sage-8.0/src/build/cythonized/sage/symbolic/function.cpp:11397)\n    res = super(BuiltinFunction, self).__call__(\n  File \"sage/symbolic/function.pyx\", line 474, in sage.symbolic.function.Function.__call__ (/ext/sage/sage-8.0/src/build/cythonized/sage/symbolic/function.cpp:6282)\n    raise TypeError(\"cannot coerce arguments: %s\" % (err))\nTypeError: cannot coerce arguments: no canonical coercion from <class 'numpy.lib.polynomial.poly1d'> to Symbolic Ring\n"}︡{"done":true}︡
︠06b1882e-7991-4cce-b5df-a656f032dc7fs︠
print(np.poly1d.integ(L0_L1(LGL_points(5))))
︡67d62dad-97ab-43ca-98b0-0670df5bc0de︡{"stdout":"         9          8          7          6         5          4\n-0.1985 x + 0.3695 x + 0.1975 x - 0.7038 x + 0.181 x + 0.3167 x\n           3\n - 0.1671 x\n"}︡{"done":true}︡
︠524bd59a-7380-4357-8e98-d7b8e37ad359s︠
print(L0_L1(LGL_points(5)))
︡43ea16c2-c12e-4e81-bca3-0786417b96f8︡{"stdout":"        8         7         6         5          4         3          2\n-1.786 x + 2.956 x + 1.383 x - 4.223 x + 0.9051 x + 1.267 x - 0.5012 x\n"}︡{"done":true}︡
︠20cd0079-36cc-418b-bd7a-fd0dc482ed9ds︠
for i in range (3, 30):
    print(np.poly1d.integ(L0_L1(LGL_points(i)))(1) - np.poly1d.integ(L0_L1(LGL_points(i)))(-1))
︡d2ff9853-de41-4c06-abb5-b5791b99edc2︡{"stdout":"0.133333333333\n0.05323971375\n0.0259259259259\n0.0144404344367\n0.00883182542984\n0.0057831752022\n0.00398834520791\n0.00286460651807\n0.00212583206209\n0.00162049687496\n0.00126330203518"}︡{"stdout":"\n0.00100374856552\n0.000810649721334\n0.000664040648327\n0.000550739482146"}︡{"stdout":"\n0.000461799455741\n0.000391029750504\n0.000333980074166"}︡{"stdout":"\n0.000287356982044\n0.000250148944115\n0.000218478781885"}︡{"stdout":"\n0.00019966664253\n0.000120453264427"}︡{"stdout":"\n-0.000364078311827\n0.00218563723183"}︡{"stdout":"\n-0.00171491554656\n-0.00311789820183"}︡{"stdout":"\n"}︡{"done":true}︡
︠32a2cf9b-69ba-4356-b8d2-01485850afc6︠










